/// MainFrame.java --- JDBForms

/// Copyright (C) 2004 Valvassori Mose <moise@valvassori.org>

/// This program is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.

/// This program is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.

/// You should have received a copy of the GNU General Public License
/// along with this program; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.jdbforms;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import javax.swing.Action;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.djedi.jdbforms.actions.*;
import org.djedi.jdbforms.forms.FormsPanel;
import org.djedi.util.Properties;
import org.djedi.swing.ToolBarButton;
import org.djedi.swing.ActionMenuItem;

/**
 * Fenetre principale
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: MainFrame.java,v 1.13 2004/06/13 09:23:34 djedi Exp $
 * @since Wed Jan 21 17:27:52 2004
 * @see JFrame
 */
public class MainFrame extends JFrame {
  private Action connectAction;
  private Action loadAction;
  private ActionMenuItem loadMi;
  private Action quitAction;
  private ActionMenuItem exportMi;
  private ToolBarButton exportBu;
  private Action exportAction;
  private JLabel status;
  private Porfolio porfolio;

  /**
   * point fixe contenant la premeire instance de MainFrame cre.
   * permet de retrouver facilement cette derniere.
   */
  private static MainFrame frame;
  

  /** Creates new form MainFrame */
  public MainFrame() {
    connectAction = new ConnectDBAction(this);
    loadAction = new LoadPortfolioAction(this);
    quitAction = new QuitAction(this);
    initComponents();
    fileMenu.add(new org.djedi.swing.ActionMenuItem(connectAction));
    loadMi=new ActionMenuItem(loadAction);
    fileMenu.add(loadMi);

    try{
      Class.forName("org.apache.poi.hssf.usermodel.HSSFWorkbook");
      exportAction = new ExportAction(this);
      exportBu = new ToolBarButton();
      exportBu.setAction(exportAction);
      jToolBar1.add(exportBu);
      exportMi=new ActionMenuItem(exportAction);
      fileMenu.add(exportMi);
    } catch (ClassNotFoundException e) {
      System.err.println("Apache POI not found.");
    }

    fileMenu.add(new org.djedi.swing.ActionMenuItem(quitAction));
      
    JPanel p = new JPanel();
    p.setLayout(new FlowLayout(FlowLayout.LEFT,1,1));
    p.setBorder(BorderFactory.createLoweredBevelBorder());
    getContentPane().add(p,BorderLayout.SOUTH);
    status = new JLabel("Ok");
    p.add(status);
    frame=this;
  }
    
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    jToolBar1 = new javax.swing.JToolBar();
    toolBarButton1 = new org.djedi.swing.ToolBarButton();
    toolBarButton2 = new org.djedi.swing.ToolBarButton();
    formsPanel = new javax.swing.JTabbedPane();
    jMenuBar2 = new javax.swing.JMenuBar();
    fileMenu = new javax.swing.JMenu();

    addWindowListener(new java.awt.event.WindowAdapter() {
	public void windowClosing(java.awt.event.WindowEvent evt) {
	  exitForm(evt);
	}
      });

    toolBarButton1.setAction(connectAction);
    jToolBar1.add(toolBarButton1);

    toolBarButton2.setAction(loadAction);
    jToolBar1.add(toolBarButton2);

    getContentPane().add(jToolBar1, java.awt.BorderLayout.NORTH);

    getContentPane().add(formsPanel, java.awt.BorderLayout.CENTER);

    fileMenu.setText("File");
    jMenuBar2.add(fileMenu);

    setJMenuBar(jMenuBar2);

  }//GEN-END:initComponents
    
  /** Exit the Application */
  private void exitForm(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_exitForm
    System.exit(0);
  }//GEN-LAST:event_exitForm
    

  /**
   * Efface tout les formulaires.
   */
  public void cleanForms() {
    formsPanel.removeAll();
  }


  public void setPorfolio(Porfolio p){
    porfolio = p;
    cleanForms();
    p.insertForm(this,formsPanel);
    loadAction.setEnabled("true".equals(getProperties().getProperty("toolbar.load.enabled","true")));
    toolBarButton2.setVisible("true".equals(getProperties().getProperty("toolbar.load.visible","true")));
    loadMi.setVisible("true".equals(getProperties().getProperty("toolbar.load.visible","true")));
    
    if (exportAction != null) {
      exportAction.setEnabled("true".equals(getProperties().getProperty("toolbar.export.enabled","true")));
      exportBu.setVisible("true".equals(getProperties().getProperty("toolbar.export.visible","true")));
      exportMi.setVisible("true".equals(getProperties().getProperty("toolbar.export.visible","true")));
    }
    pack();
  }

  public FormsPanel getTopForm(){
    return (FormsPanel)formsPanel.getSelectedComponent();
  }

  public Properties getProperties() {
    return porfolio.getProperties();
  }

  /**
   * change la ligne de status
   * @param s the new status
   */
  public void setStatus(String s) {
    status.setText(s);
  }
  public static MainFrame getFrame() {
    return frame;
  }
    
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JMenu fileMenu;
  private javax.swing.JTabbedPane formsPanel;
  private javax.swing.JMenuBar jMenuBar2;
  private javax.swing.JToolBar jToolBar1;
  private org.djedi.swing.ToolBarButton toolBarButton1;
  private org.djedi.swing.ToolBarButton toolBarButton2;
  // End of variables declaration//GEN-END:variables
    
}
