//   ExportAction.java --- JDBForms

//   Copyright (C) 2004 Valvassori Mose <moise@valvassori.org>

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.jdbforms.actions;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import org.djedi.jdbforms.*;
import org.apache.poi.hssf.usermodel.*;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.util.HSSFColor;
import java.io.FileOutputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import javax.swing.table.TableModel;
import javax.swing.JFileChooser;
import java.io.File;
import javax.swing.filechooser.FileFilter;


/**
 * Action qui exporte les resultat vers exel  ...
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: ExportAction.java,v 1.1 2004/06/12 18:02:25 djedi Exp $
 * @since Sat Jun 12 16:13:38 CEST 2004
 */
public class ExportAction extends AbstractAction {
  public ExportAction (MainFrame f) {
    super(f, "Export",
 	  "/toolbarButtonGraphics/general/Export24.gif",
 	  "/toolbarButtonGraphics/general/Export16.gif",
	  "Export to XLS", KeyEvent.VK_E);
  }

  public void actionPerformed(ActionEvent e) {
    try{
      TableModel m = ((MainFrame)frame).getTopForm().getExportable();
      if (m==null)
	return;

      System.out.println("Export: "+m);

      JFileChooser f = new JFileChooser();
      f.setFileFilter(new FileFilter(){
	  public boolean accept(File fi) {
	    if (fi.isDirectory())
	      return true;
	    else if (fi.canRead() &&
		     fi.getName().endsWith("xls"))
	      return true;
	    return false;
	  }
	  public String getDescription(){
	    return "Excel (*.xls)";
	  }
	});
      if (f.showSaveDialog(frame) != JFileChooser.APPROVE_OPTION)
	return;

      HSSFWorkbook wb = new HSSFWorkbook();
      HSSFSheet sheet = wb.createSheet("JDBForms");
    
//       HSSFHeader header = sheet.getHeader();
//       header.setCenter("Center Header");
//       header.setLeft("Left Header");
//       header.setRight(HSSFHeader.font("Stencil-Normal", "Italic") + 
// 		      HSSFHeader.fontSize((short) 16) + "Right w/ Stencil-Normal Italic font and size 16");
      HSSFCellStyle style = wb.createCellStyle();
      style.setBorderBottom(HSSFCellStyle.BORDER_MEDIUM);
      style.setBottomBorderColor(HSSFColor.BLACK.index);
      HSSFFont font = wb.createFont();
      font.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
      style.setFont(font);

      HSSFRow row = sheet.createRow((short)0);
      for (int i=0; i<m.getColumnCount(); i++){
	  HSSFCell cell = row.createCell((short)i);
	  cell.setCellValue(m.getColumnName(i));
	  cell.setCellStyle(style);
      }

      for (int j=0; j<m.getRowCount(); j++) {
	row = sheet.createRow((short)j+1);
	for (int i=0; i<m.getColumnCount(); i++)
	  row.createCell((short)i).setCellValue(m.getValueAt(j,i).toString());
      }
      // Write the output to a file
      FileOutputStream fileOut = new FileOutputStream(f.getSelectedFile());
      wb.write(fileOut);
      fileOut.close();
    } catch (FileNotFoundException ex) {
      ex.printStackTrace();
    } catch (IOException ex) {
      ex.printStackTrace();      
    }
  } 
}
