//   IntEntry.java --- Jdbforms

//   Copyright (C) 2004 Valvassori Mose <moise@valvassori.org>

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.jdbforms.entries;

import javax.swing.InputVerifier;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JTextField;
import java.awt.event.ActionListener;

/**
 * Une entre Entire.
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: IntEntry.java,v 1.9 2004/06/12 11:16:31 djedi Exp $
 * @since Sat Jan 17 16:27:04 2004
 */
public class IntEntry extends Entry{
  private static IntVerifier iv = null;
  private JLabel title;
  private JTextField tf;

  /**
   * Creates a new <code>TextEntry</code> instance.
   *
   */
  public IntEntry (String text) {
    title = new JLabel(text);
    add(title);

    tf = new JTextField();
    tf.setColumns(10);
    
    if (iv==null)
      iv = new IntVerifier();
    tf.setInputVerifier(iv);
    add(tf);
  }

  /**
   * Get the Title value.
   * @return the Title value.
   */
  public String getTitle() {
    return title.getText();
  }

  /**
   * Set the Title value.
   * @param newTitle The new Title value.
   */
  public void setTitle(String newTitle) {
    title.setText(newTitle);
  }


  /**
   * Get the Integer value.
   * @return the Integer value.
   */
  public int getInteger() {
    return Integer.parseInt(tf.getText());
  }

  /**
   * Set the Integer value.
   * @param newInteger The new Integer value.
   */
  public void setInteger(int newInteger) {
    tf.setText(Integer.toString(newInteger));
  }

  public void setDefault(String defaut) {
    setInteger(Integer.parseInt(defaut));
  }

  public void addActionListener(ActionListener a) {
    tf.addActionListener(a);
  }

  public String getRawSQLValue() {
    return getSQLValue();
  }
  public String getSQLValue() {
    if ("".equals(tf.getText()))
      return "";
    return Integer.toString(getInteger());
  }

  public boolean isEmpty() {
    try {
      getInteger();
      return false;
    } catch (NumberFormatException e) {
      return true;
    }
  }
  
  /**
   * Verifie que l'on a bien taper un entier.
   * @author "Valvassori Mose" <moise@valvassori.org>
   * @version $Id: IntEntry.java,v 1.9 2004/06/12 11:16:31 djedi Exp $
   * @since Sun Jan 18 10:40:27 2004
   * @see InputVerifier
   */
  public class IntVerifier extends InputVerifier {
    public boolean verify(JComponent c) {
      try{
	Integer.valueOf(((JTextField)c).getText());
	return true;
      } catch (NumberFormatException e) {
	return false;
      }
    }
  }
}
