//   FormsPanel.java --- Jdbforms

//   Copyright (C) 2004 Valvassori Mose <moise@valvassori.org>

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.jdbforms.forms;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.HashMap;
import java.util.Iterator;
import java.util.StringTokenizer;
import java.util.Vector;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.djedi.jdbforms.entries.Entry;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import javax.swing.table.TableModel;
import javax.swing.Icon;



/**
 * Un formulaire.
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: FormsPanel.java,v 1.6 2004/06/13 09:23:35 djedi Exp $
 * @since Sat Jan 17 15:57:08 2004
 */
public abstract class FormsPanel extends JPanel {
  private Element doc;
  private HashMap entrytosqlelt;
  private HashMap idtoentry;
  private Icon icon;

  protected TableModel exportable = null;


  /**
   * Creates a new <code>FormsPanel</code> instance.
   *
   */
  public FormsPanel (Element elt) {
    this.doc = elt;
    setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
    entrytosqlelt = new HashMap();
    idtoentry = new HashMap();

    if (elt==null)
      return;

    if (!"form".equals(elt.getTagName()))
      return;

    setName(elt.getAttribute("title"));
  }


  /**
   * Genere les boutons qui valide le formulaire.
   */
  protected void validToolbar(){
    JPanel p = new JPanel(new FlowLayout(FlowLayout.RIGHT));
    JButton bok = new JButton("Valid");
    JButton breset = new JButton("Reset");
    bok.addActionListener(new OkActionListener(this));
    breset.setEnabled(false);
    p.add(bok);
    p.add(breset);
    add(p,BorderLayout.SOUTH);    
  }

  /**
   * fabrique le formulaire
   */
  protected void composeForm(Element elt, Container c) {
    NodeList nl = elt.getChildNodes();
    for (int i=0; i<nl.getLength(); i++)
      if ("entry".equals(nl.item(i).getNodeName()))
	addEntry(nl.item(i),c);
      else if ("group".equals(nl.item(i).getNodeName()))
	addGroup(nl.item(i),c);
      else if ("text".equals(nl.item(i).getNodeName()))
	addText(nl.item(i),c);
  }


  /**
   * Ajoute un gorupe
   * @param n le noeud  ajouter
   * @param c le container qui contiendra le groupe.
   */
  private void addGroup(Node n, Container c) {
    Element e = (Element)n;
    JPanel p = new JPanel();
    p.setLayout(new BoxLayout(p,BoxLayout.Y_AXIS));
    p.setBorder(BorderFactory.createTitledBorder(e.getAttribute("title")));
    c.add(p);
    composeForm(e,p);
  }

  /**
   *
   * @param n a <code>Node</code> value
   * @param c a <code>Container</code> value
   */
  private void addText(Node n, Container c) {
    Element e = (Element)n;
    n.normalize();
    c.add(new JLabel(n.getFirstChild().getNodeValue()));
  }




  private static Entry nullEntry = new org.djedi.jdbforms.entries.NullEntry();
  /**
   * Ajoute une entre.
   * @todo modifier cela afin d'utilisation des beans et un chargement a la vole
   * @param n a <code>Node</code> value
   * @param c a <code>Container</code> value
   */
  private void addEntry(Node n, Container c) {
    Entry jc = nullEntry;
    Element e = (Element)n;

    if ("".equals(e.getAttribute("typeref"))){
      if ("text".equals(e.getAttribute("type")))
	jc = new org.djedi.jdbforms.entries.TextEntry(e.getAttribute("title"));
      else if ("int".equals(e.getAttribute("type")))
	jc = new org.djedi.jdbforms.entries.IntEntry(e.getAttribute("title"));
      else if ("date".equals(e.getAttribute("type")))
	jc = new org.djedi.jdbforms.entries.DateEntry(e.getAttribute("title"));
      else if ("sqldata".equals(e.getAttribute("type"))){
	//* @warning ne verifie pas si la Node-liste est vide
	Element elt = ((Element)e.getElementsByTagName("query").item(0));
	jc = new org.djedi.jdbforms.entries.SQLEntry(e.getAttribute("title"),elt);
      }
      else if ("textarea".equals(e.getAttribute("type")))
	jc = new org.djedi.jdbforms.entries.TextAreaEntry(e.getAttribute("title"));
      else if ("boolean".equals(e.getAttribute("type")))
	jc = new org.djedi.jdbforms.entries.BooleanEntry(e.getAttribute("title"));

    } else {

      Element type = doc.getOwnerDocument().getElementById(e.getAttribute("typeref"));
      Node nl = type.getFirstChild();
      Vector o = null;
      StringTokenizer stk = new StringTokenizer(nl.getNodeValue(),",");
      o = new Vector(stk.countTokens());
      while (stk.hasMoreElements())
	o.add(stk.nextElement());

      if ("text".equals(e.getAttribute("type")))
	jc = new org.djedi.jdbforms.entries.EnumEntry(e.getAttribute("title"),o);
      // else if ("int".equals(e.getAttribute("type")))
      // 	jc = new org.djedi.jdbforms.entries.IntEntry(e.getAttribute("title"));      
    }

    if (!"".equals(e.getAttribute("id")))
      idtoentry.put(e.getAttribute("id"),jc);

    if (!"".equals(e.getAttribute("depends"))){
      jc.setEnabled(false);
      ((Entry)idtoentry.get(e.getAttribute("depends"))).
	addActionListener(new DependsActionListener(jc));
    }

    if (!"".equals(e.getAttribute("default"))){
      jc.setDefault(e.getAttribute("default"));
    }
    
    entrytosqlelt.put(jc,n);
    c.add(jc);
  }


  public Iterator getElements() {
    return entrytosqlelt.entrySet().iterator();
  }
  public Element getRootElement() {
    return doc;
  }
  public Entry getEntryByID(String id) {
    return (Entry)idtoentry.get(id);
  }

  protected abstract void actionPerformed(ActionEvent actionEvent);


  public TableModel getExportable(){
    return exportable;
  }

  protected void setIcon(Icon i){
    icon = i;
  }
  public Icon getIcon(){
    return icon;
  }


  /**
   *
   * @author "Valvassori Mose" <moise@valvassori.org>
   * @version $Id: FormsPanel.java,v 1.6 2004/06/13 09:23:35 djedi Exp $
   * @since Sun Jan 18 11:30:50 2004
   * @see ActionListener
   */
  protected class DependsActionListener implements ActionListener {
    private Entry entry;
    public DependsActionListener(Entry e) {
      entry = e;
    }

    /**
     * Describe <code>actionPerformed</code> method here.
     *
     * @param actionEvent an <code>ActionEvent</code> value
     */
    public void actionPerformed(ActionEvent actionEvent) {
      entry.setEnabled(!"".equals(actionEvent.getActionCommand()));
    }
  }

  protected class OkActionListener implements ActionListener {
    private FormsPanel f;
    public OkActionListener(FormsPanel f) {
      this.f = f;
    }

    /**
     * Describe <code>actionPerformed</code> method here.
     *
     * @param actionEvent an <code>ActionEvent</code> value
     */
    public void actionPerformed(ActionEvent actionEvent) {
      f.actionPerformed(actionEvent);
    }
  }

}
