//   JarClassFinder.java --- DJedi Lib

//   Copyright (C) 2004 Valvassori Mose <moise@valvassori.org>

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.util;
import java.util.jar.JarFile;
import java.io.File;
import java.io.IOException;
import java.net.URLClassLoader;
import java.util.Enumeration;
import java.util.jar.JarEntry;
import java.io.InputStream;
import java.net.URL;
import java.io.BufferedInputStream;
import java.util.LinkedList;
import java.util.List;



/**
 * Trouve une instance d'une classe dans un JAR
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: JarClassFinder.java,v 1.2 2004/01/24 18:21:29 djedi Exp $
 * @since Sat Jan 24 11:02:28 2004
 */
public class JarClassFinder {
  private JarFile jar;
  private ByteClassLoader clo;

  /**
   * Creates a new <code>JarClassFinder</code> instance.
   *
   */
  public JarClassFinder (File f) {
    try {
      jar = new JarFile(f);
      URL urls [] = {f.toURL()};
      clo = new ByteClassLoader(new URLClassLoader(urls));
    } catch (IOException e) {
      e.printStackTrace();
    }
  }


  /**
   * Trouve toutes les classes contenues dans une jar et implmentant
   * father.
   * @param father a <code>Class</code> value
   * @return a <code>List</code> value
   */
  public List find (Class father) {
    LinkedList list = new LinkedList();
    for (Enumeration e = jar.entries(); e.hasMoreElements();)
      try {
	JarEntry en = (JarEntry)e.nextElement();
	if (!en.getName().endsWith(".class"))
	  continue;

	//	System.out.println(en+" "+en.getSize());
	byte b[] = new byte[(int)en.getSize()];
	InputStream inp = new BufferedInputStream(jar.getInputStream(en));
	inp.read(b);
	inp.close();

	try {
	  Class cla = clo.defineClass(b);
	  if (father.isAssignableFrom(cla))
	    list.add(cla);
	} catch (LinkageError ex) {
	}
      } catch (IOException ex) {
	ex.printStackTrace();
      }
    return list;
  }

  /**
   * Renvoie le jar.
   * @return a <code>Jar</code> value
   */
  public JarFile getJar() {
    return jar;
  }

  public static void main(String[] args) throws Exception{
    JarClassFinder j = new JarClassFinder(new File(args[0]));
    System.out.println(j.find(java.sql.Driver.class));
  }
}
