//   Properties.java --- DJedi Lib

//   Copyright (C) 2004 Valvassori Mose <moise@valvassori.org>

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;



/**
 * Une proprit
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: Properties.java,v 1.2 2004/01/29 08:26:32 djedi Exp $
 * @since Wed Jan 28 21:43:21 2004
 */
public class Properties extends java.util.Properties {
  public Properties (java.util.Properties prop) {
    super(prop);
  }
  public Properties () {
    super();
  }


  /**
   * Charge un fichier de proprit. Le fichier peut tre sous plusieurs forme:
   * <ul>
   *  <li><tt>$HOME/.fichier</tt></li>
   *  <li><tt>./.fichier</tt></li>
   *  <li><tt>./fichier</tt></li>
   * </ul>
   * @param prop la cl du fichier de proprite
   */
  public void loadProperties(String prop) {
    File f;

    // Properties dans le home
    try {
      f = new File (System.getProperty("user.home"),"."+prop);
      if (f.exists())
       load(new FileInputStream(f));
    } catch (IOException  e) {
      System.err.println("Error reading: "+new File (System.getProperty("user.home"),"."+prop));
    }

    // Properties cach dans le rep courant.
    try {
      f = new File (System.getProperty("user.dir"),"."+prop);
      if (f.exists())
	load(new FileInputStream(f));
    } catch (IOException  e) {
      System.err.println("Error reading: "+new File (System.getProperty("user.dir"),"."+prop));
    }
    // Properties dans le rep courant.
    try {
      f = new File (System.getProperty("user.dir"),prop);
      if (f.exists())
	load(new FileInputStream(f));
    } catch (IOException  e) {
      System.err.println("Error reading: "+new File (System.getProperty("user.dir"),prop));
    }
  }

}
