//   XMLFacade.java --- DJedi utily classes

//   Copyright (C) 2003 Valvassori Mose <moise@valvassori.org>

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.djedi.xml;
import java.io.IOException;
import java.io.OutputStream;
import java.io.Writer;
import java.net.URL;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

/**
 * A facade to the XML Framework.
 * @author "Valvassori Mose" <moise@valvassori.org>
 * @version $Id: XMLFacade.java,v 1.1 2004/01/17 15:48:55 djedi Exp $
 * @since Wed Oct  1 10:34:42 2003
 */
public class XMLFacade {
  private static XMLFacade facade = null;
  private DocumentBuilderFactory dbf;
  private DocumentBuilder db;

  /**
   * Creates a new <code>XMLFacade</code> instance.
   *
   */
  protected XMLFacade () {
    try {
    dbf = DocumentBuilderFactory.newInstance();
    dbf.setNamespaceAware(true);
    db = dbf.newDocumentBuilder();
    db.setErrorHandler(new _ErrorHandler());

    } catch (ParserConfigurationException e) {
      //      org.djedi.jcsound.ExceptionManager.raise("Can't configure the XML Parser",e);
      e.printStackTrace();
    }
  }

  /**
   * Singleton pattern Implementation 
   * @return a <code>XMLFacade</code> value
   */
  public static XMLFacade createFacade() {
    if ( facade==null)
      facade=new XMLFacade();
    return facade;
  }


  /**
   * Read and return an XML Document from an URL.
   * @param url an <code>URL</code> value
   * @return a <code>Document</code> value
   */
  public Document readDocument(URL url) {
    try{ 
      return db.parse(url.toString());
    } catch (SAXException e) {
      //      org.djedi.jcsound.ExceptionManager.raise("Error reading XML file: "+url,e);
      e.printStackTrace();
    } catch (IOException e) {
      e.printStackTrace();
      //      org.djedi.jcsound.ExceptionManager.raise("Error in XML File: "+url,e);
    }
    return null;
  }

  /**
   * Construit un document autour d'un element.
   * @param el an <code>Element</code> value
   * @return a <code>Document</code> value
   */
  public Document newDocument(Element el) {
    Document doc = db.newDocument();
    doc.appendChild(doc.importNode(el,true));

    return doc;
  }

  /**
   * Contruit un document vide.
   * @return a <code>Document</code> value
   */
  public Document newDocument() {
    return db.newDocument();
  }

  public void toStream(Document document, OutputStream out){
    toStream(document,new java.io.OutputStreamWriter(out));
  }

  public void toStream(Document document, Writer out){
    // try {
    //   OutputFormat format = new OutputFormat(document);
    //   format.setLineWidth(10);
    //   format.setIndenting(true);
    //   format.setIndent(1);
    //   format.setMethod("xml");
    //   XMLSerializer serializer = new XMLSerializer (out, format);
    //   serializer.asDOMSerializer();
    //   serializer.serialize(document); 
    // } catch (IOException e) {
    //   org.djedi.jcsound.ExceptionManager.raise("Can't write XML",e);
    // }
  }

  private class _ErrorHandler implements ErrorHandler {
    
    // Implementation of org.xml.sax.ErrorHandler

    /**
     * Describe <code>error</code> method here.
     *
     * @param saxe a <code>SAXParseException</code> value
     * @exception SAXException if an error occurs
     */
    public void error(SAXParseException saxe) throws SAXException {
      System.err.println("XML Error at "+saxe.getSystemId()+" "+saxe.getColumnNumber()+":"+saxe.getLineNumber());
      throw saxe;
    }

    /**
     * Describe <code>warning</code> method here.
     *
     * @param SAXParseException a <code>SAXParseException</code> value
     * @exception SAXException if an error occurs
     */
    public void warning(SAXParseException saxe) throws SAXException {
      System.err.println("XML Warning at "+saxe.getSystemId()+" "+saxe.getColumnNumber()+":"+saxe.getLineNumber());
      throw saxe;
    }

    /**
     * Describe <code>fatalError</code> method here.
     *
     * @param SAXParseException a <code>SAXParseException</code> value
     * @exception SAXException if an error occurs
     */
    public void fatalError(SAXParseException saxe) throws SAXException {
      System.err.println("Fatal XML Error at "+saxe.getSystemId()+" "+saxe.getColumnNumber()+":"+saxe.getLineNumber());
      throw saxe;
    }
  }
}
